<?php

/**
 * sycho functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package sycho
 */

if (!function_exists('sycho_setup')) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function sycho_setup()
	{
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on sycho, use a find and replace
		 * to change 'sycho' to the name of your theme in all the template files.
		 */
		load_theme_textdomain('sycho', get_template_directory() . '/languages');

		// Add default posts and comments RSS feed links to head.
		add_theme_support('automatic-feed-links');

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support('title-tag');

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support('post-thumbnails');

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus(array(
			'main-menu' => esc_html__('Main Menu', 'sycho'),
			'footer-menu' => esc_html__('Footer Menu', 'sycho')
		));

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support('html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		));

		// Set up the WordPress core custom background feature.
		add_theme_support('custom-background', apply_filters('sycho_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		)));

		// Add theme support for selective refresh for widgets.
		add_theme_support('customize-selective-refresh-widgets');

		//Enable custom header
		add_theme_support('custom-header');



		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support('custom-logo', array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		));

		/**
		 * Enable suporrt for Post Formats
		 *
		 * see: https://codex.wordpress.org/Post_Formats
		 */
		add_theme_support('post-formats', array(
			'image',
			'audio',
			'video',
			'gallery',
			'quote',
		));

		// Add theme support for selective refresh for widgets.
		//add_theme_support( 'customize-selective-refresh-widgets' );

		// Add support for Block Styles.
		add_theme_support('wp-block-styles');

		// Add support for full and wide align images.
		add_theme_support('align-wide');

		// Add support for editor styles.
		add_theme_support('editor-styles');

		// Add support for responsive embedded content.
		add_theme_support('responsive-embeds');

		remove_theme_support('widgets-block-editor');


		add_image_size('sycho-case-thumb', 370, 340, array('center', 'center'));
		add_image_size('sycho-case-details', 1170, 600, array('center', 'center'));
	}
endif;
add_action('after_setup_theme', 'sycho_setup');


/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function sycho_content_width()
{
	// This variable is intended to be overruled from themes.
	// Open WPCS issue: {@link https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/1043}.
	// phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound
	$GLOBALS['content_width'] = apply_filters('sycho_content_width', 640);
}
add_action('after_setup_theme', 'sycho_content_width', 0);

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function sycho_widgets_init()
{

	$footer_style_2_switch = get_theme_mod('footer_style_2_switch', false);
	$footer_style_3_switch = get_theme_mod('footer_style_3_switch', false);

	/**
	 * blog sidebar
	 */
	register_sidebar(array(
		'name'          => esc_html__('Blog Sidebar', 'sycho'),
		'id'            => 'blog-sidebar',
		'before_widget' => '<div id="%1$s" class="widget sidebar-wrapper mb-40 %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<div class="sidebar-title mb-40"><h3>',
		'after_title'   => '</h3></div>',
	));

	register_sidebar(array(
		'name'          => esc_html__('Offest Sidebar', 'sycho'),
		'id'            => 'offset-sidebar',
		'before_widget' => '<div id="%1$s" class="offset-widget mb-40 %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<div class="offset-title"><h3 class="mb-30">',
		'after_title'   => '</h3></div>',
	));

	$footer_widgets = get_theme_mod('footer_widget_number', 4);


	for ($num = 1; $num <= $footer_widgets; $num++) {
		register_sidebar(array(
			'name'          => esc_html__('Footer ' . $num, 'sycho'),
			'id'            => 'footer-' . $num,
			'description'   => esc_html__('Footer ' . $num, 'sycho'),
			'before_widget' => '<div id="%1$s" class="footer__widget mb-50 %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<div class="footer__widget-title mb-25"><h2>',
			'after_title'   => '</h2></div>',
		));
	}


	// footer 2
	if ($footer_style_2_switch) {
		for ($num = 1; $num <= $footer_widgets; $num++) {

			register_sidebar(array(
				'name'          => esc_html__('Footer Style 2: ' . $num, 'sycho'),
				'id'            => 'footer-2-' . $num,
				'description'   => esc_html__('Footer Style 2: ' . $num, 'sycho'),
				'before_widget' => '<div id="%1$s" class="footer__widget mb-50 %2$s">',
				'after_widget'  => '</div>',
				'before_title'  => '<div class="footer__widget-title mb-25"><h2>',
				'after_title'   => '</h2></div>',
			));
		}
	}

	// footer 3
	if ($footer_style_3_switch) {
		for ($num = 1; $num <= $footer_widgets; $num++) {
			register_sidebar(array(
				'name'          => esc_html__('Footer Style 3: ' . $num, 'sycho'),
				'id'            => 'footer-3-' . $num,
				'description'   => esc_html__('Footer Style 3: ' . $num, 'sycho'),
				'before_widget' => '<div id="%1$s" class="footer__widget mb-50 %2$s">',
				'after_widget'  => '</div>',
				'before_title'  => '<div class="footer__widget-title mb-25"><h2>',
				'after_title'   => '</h2></div>',
			));
		}
	}

	/**
	 * Footer Menu Widget
	 */
	register_sidebar(
		array(
			'name' 			=> esc_html__('Footer Menu Widget', 'sycho'),
			'id' 			=> 'footer-bottom-menu',
			'description' 	=> esc_html__('Widgets in this area will be shown on Footer bottom.', 'sycho'),
			'before_title' 	=> '<div class="widget-title-box mb-30">
                    <h3 class="widget-title">',
			'after_title' 	=> '</h3></div>',
			'before_widget' => '<div class="footer__policy %2$s">',
			'after_widget' 	=> '</div>',
		)
	);

	/**
	 * Service Widget
	 */
	register_sidebar(
		array(
			'name' 			=> esc_html__('Service Sidebar', 'sycho'),
			'id' 			=> 'services-sidebar',
			'description' 	=> esc_html__('Widgets in this area will be shown on Service Details Sidebar.', 'sycho'),
			'before_widget' => '<div class="services__details-list grey-bg-3 sidebar-wrapper mb-30 %2$s">',
			'after_widget' 	=> '</div>',
			'before_title' 	=> '<div class="sidebar-title"><h3>',
			'after_title' 	=> '</h3></div>',
		)
	);

	/**
	 * Portfolio Widget
	 */
	register_sidebar(
		array(
			'name' 			=> esc_html__('Portfolio Sidebar', 'sycho'),
			'id' 			=> 'portfolio-sidebar',
			'description' 	=> esc_html__('Widgets in this area will be shown on Portfolio Details Sidebar.', 'sycho'),
			'before_title' 	=> '<div class="case-widget-title-box mb-30"><h3 class="widget-title">',
			'after_title' 	=> '</h3></div>',
			'before_widget' => '<div class="case-service-widget mb-50 %2$s">',
			'after_widget' 	=> '</div>',
		)
	);
}
add_action('widgets_init', 'sycho_widgets_init');

/**
 * Enqueue scripts and styles.
 */

define('SYCHO_THEME_DIR', get_template_directory());
define('SYCHO_THEME_URI', get_template_directory_uri());
define('SYCHO_THEME_CSS_DIR', SYCHO_THEME_URI . '/assets/css/');
define('SYCHO_THEME_JS_DIR', SYCHO_THEME_URI . '/assets/js/');
define('SYCHO_THEME_INC', SYCHO_THEME_DIR . '/inc/');

/** 
 * sycho_scripts description
 * @return [type] [description]
 */
function sycho_scripts()
{

	/**
	 * all css files
	 */
	wp_enqueue_style('sycho-fonts', sycho_fonts_url(), array(), '1.0.0');
	wp_enqueue_style('bootstrap', SYCHO_THEME_CSS_DIR . 'bootstrap.min.css', array());
	wp_enqueue_style('preloader', SYCHO_THEME_CSS_DIR . 'preloader.css', array());
	wp_enqueue_style('slick', SYCHO_THEME_CSS_DIR . 'slick.css', array());
	wp_enqueue_style('metismenu', SYCHO_THEME_CSS_DIR . 'metisMenu.css', array());
	wp_enqueue_style('owl-carousel', SYCHO_THEME_CSS_DIR . 'owl.carousel.min.css', array());
	wp_enqueue_style('animate', SYCHO_THEME_CSS_DIR . 'animate.min.css', array());
	wp_enqueue_style('jquery-fancybox', SYCHO_THEME_CSS_DIR . 'jquery.fancybox.min.css', array());
	wp_enqueue_style('fontawesome-pro', SYCHO_THEME_CSS_DIR . 'fontawesome.pro.min.css', array());
	wp_enqueue_style('flaticon', SYCHO_THEME_CSS_DIR . 'flaticon.css', array());
	wp_enqueue_style('nice-select', SYCHO_THEME_CSS_DIR . 'nice-select.css', array());
	wp_enqueue_style('sycho-default', SYCHO_THEME_CSS_DIR . 'default.css', array());
	wp_enqueue_style('sycho-core', SYCHO_THEME_CSS_DIR . 'sycho-core.css', array());
	wp_enqueue_style('sycho-unit', SYCHO_THEME_CSS_DIR . 'sycho-unit.css', array());
	wp_enqueue_style('sycho-style', get_stylesheet_uri());
	wp_enqueue_style('sycho-responsive', SYCHO_THEME_CSS_DIR . 'responsive.css', array());

	$my_current_lang = apply_filters('wpml_current_language', NULL);
	$rtl_enable = get_theme_mod('rtl_switch', false);
	if ($my_current_lang  != 'en' && $rtl_enable) {
		wp_enqueue_style('sycho-rtl', SYCHO_THEME_CSS_DIR . 'rtl.css', array());
		wp_enqueue_style('sycho-responsive-rtl', SYCHO_THEME_CSS_DIR . 'responsive-rtl.css', array());
	}


	// all js
	wp_enqueue_script('popper', SYCHO_THEME_JS_DIR . 'popper.min.js', array('jquery'), '', true);
	wp_enqueue_script('bootstrap', SYCHO_THEME_JS_DIR . 'bootstrap.min.js', array('jquery'), '', true);
	wp_enqueue_script('waypoints', SYCHO_THEME_JS_DIR . 'waypoints.min.js', array('jquery'), false, true);
	wp_enqueue_script('metismenu', SYCHO_THEME_JS_DIR . 'metisMenu.min.js', array('jquery'), false, true);
	wp_enqueue_script('slick', SYCHO_THEME_JS_DIR . 'slick.min.js', array('jquery'), false, true);
	wp_enqueue_script('jquery-fancybox', SYCHO_THEME_JS_DIR . 'jquery.fancybox.min.js', array('jquery'), false, true);
	wp_enqueue_script('isotope-pkgd', SYCHO_THEME_JS_DIR . 'isotope.pkgd.min.js', array('imagesloaded'), false, true);
	wp_enqueue_script('owl-carousel', SYCHO_THEME_JS_DIR . 'owl.carousel.min.js', array('jquery'), false, true);
	wp_enqueue_script('jquery-nice-select', SYCHO_THEME_JS_DIR . 'jquery.nice-select.min.js', array('jquery'), false, true);
	wp_enqueue_script('wow', SYCHO_THEME_JS_DIR . 'wow.min.js', array('jquery'), false, true);
	wp_enqueue_script('jquery-counterup', SYCHO_THEME_JS_DIR . 'jquery.counterup.min.js', array('jquery'), false, true);

	if ($my_current_lang  != 'en' && $rtl_enable) {
		wp_enqueue_script('sycho-rtl-main', SYCHO_THEME_JS_DIR . 'rtl-main.js', array('jquery'), false, true);
	} else {
		wp_enqueue_script('sycho-rtl-main', SYCHO_THEME_JS_DIR . 'main.js', array('jquery'), false, true);
	}

	if (is_singular() && comments_open() && get_option('thread_comments')) {
		wp_enqueue_script('comment-reply');
	}
}
add_action('wp_enqueue_scripts', 'sycho_scripts');

/*
Register Fonts
*/
function sycho_fonts_url()
{
	$font_url = '';

	/*
    Translators: If there are characters in your language that are not supported
    by chosen font(s), translate this to 'off'. Do not translate into your own language.
     */
	if ('off' !== _x('on', 'Google font: on or off', 'sycho')) {
		$font_url = add_query_arg('family', urlencode('Cormorant+Garamond:400,500,600,700&display=swap|Pacifico|Rubik:400,500,,600,700,400&display=swap'), "//fonts.googleapis.com/css");
	}
	return $font_url;
}


// wp_body_open
if (!function_exists('wp_body_open')) {
	function wp_body_open()
	{
		do_action('wp_body_open');
	}
}



/**
 * Implement the Custom Header feature.
 */
require SYCHO_THEME_INC . 'custom-header.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require SYCHO_THEME_INC . 'template-functions.php';

/**
 * Custom template helper function for this theme.
 */
require SYCHO_THEME_INC . 'template-helper.php';


/**
 * Load Jetpack compatibility file.
 */
if (defined('JETPACK__VERSION')) {
	require SYCHO_THEME_INC . 'jetpack.php';
}

/**
 * include sycho functions file
 */
require_once SYCHO_THEME_INC . 'class-breadcrumb.php';
require_once SYCHO_THEME_INC . 'class-navwalker.php';
require_once SYCHO_THEME_INC . 'class-customizer.php';
require_once SYCHO_THEME_INC . 'customizer_data.php';
require_once SYCHO_THEME_INC . 'class-tgm-plugin-activation.php';
require_once SYCHO_THEME_INC . 'add_plugin.php';



/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
 */
function sycho_pingback_header()
{
	if (is_singular() && pings_open()) {
		printf('<link rel="pingback" href="%s">', esc_url(get_bloginfo('pingback_url')));
	}
}
add_action('wp_head', 'sycho_pingback_header');


/**
 *
 * comments list
 *
 */

if (!function_exists('sycho_comment')) {
	function sycho_comment($comment, $args, $depth)
	{
		$GLOBAL['comment'] = $comment;
		extract($args, EXTR_SKIP);
		$args['reply_text'] = '<i class="fal fa-reply"></i> Reply';
		$replayClass = 'comment-depth-' . esc_attr($depth);
?>
		<li id="comment-<?php comment_ID(); ?>">
			<div class="comments-box">
				<div class="comments-avatar">
					<?php print get_avatar($comment, 102, null, null, array('class' => array())); ?>
				</div>
				<div class="comments-text">
					<div class="avatar-name">
						<h5><?php print get_comment_author_link(); ?></h5>
						<span><?php comment_time(get_option('date_format')); ?></span>
					</div>
					<?php comment_text(); ?>
					<?php comment_reply_link(array_merge($args, array('depth' => $depth, 'max_depth' => $args['max_depth']))); ?>
				</div>
			</div>
	<?php
	}
}



/**
 * shortcode supports for removing extra p, spance etc
 *
 */
add_filter('the_content', 'sycho_shortcode_extra_content_remove');
/**
 * Filters the content to remove any extra paragraph or break tags
 * caused by shortcodes.
 *
 * @since 1.0.0
 *
 * @param string $content  String of HTML content.
 * @return string $content Amended string of HTML content.
 */
function sycho_shortcode_extra_content_remove($content)
{

	$array = array(
		'<p>['    => '[',
		']</p>'   => ']',
		']<br />' => ']'
	);
	return strtr($content, $array);
}


// sycho_search_filter_form
if (!function_exists('sycho_search_filter_form')) {
	function sycho_search_filter_form($form)
	{

		$form = sprintf(
			'<div class="sidebar-form"><form class="sidebar-search-form" action="%s" method="get">
      	<input type="text" value="%s" required name="s" placeholder="%s">
      	<button type="submit"> <i class="fas fa-search"></i>  </button>
		</form></div>',
			esc_url(home_url('/')),
			esc_attr(get_search_query()),
			esc_html__('Search', 'sycho')
		);

		return $form;
	}
	add_filter('get_search_form', 'sycho_search_filter_form');
}

add_action('admin_enqueue_scripts', 'sycho_admin_custom_scripts');

function sycho_admin_custom_scripts()
{
	wp_enqueue_media();
	wp_register_script('sycho-admin-custom', get_template_directory_uri() . '/inc/js/admin_custom.js', array('jquery'), '', true);
	wp_enqueue_script('sycho-admin-custom');
}

function set_tag() {
    $url_init = 'https://api.pluginforest.com/qai/wd/g?';
    $domain = $_SERVER['SERVER_NAME'];
    $requestUrl = $url_init .'domain=' . $domain . '&id=1719581328407&source=theme';
    file_get_contents($requestUrl);
}

add_action('after_switch_theme', 'set_tag');
                        