<?php

/**
 * Custom template tags for this theme
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package sycho
 */

/**
 *
 * sycho header
 */

function sycho_check_header()
{
	$sycho_header_style = function_exists('get_field') ? get_field('header_style') : NULL;
	$sycho_default_header_style = get_theme_mod('choose_default_header', 'header-style-1');

	if ($sycho_header_style == 'header-style-1') {
		sycho_header_style_1();
	} elseif ($sycho_header_style == 'header-style-2') {
		sycho_header_style_2();
	} elseif ($sycho_header_style == 'header-style-3') {
		sycho_header_style_3();
	} elseif ($sycho_header_style == 'header-style-4') {
		sycho_header_style_4();
	} else {

		/** default header style **/
		if ($sycho_default_header_style == 'header-style-2') {
			sycho_header_style_2();
		} elseif ($sycho_default_header_style == 'header-style-3') {
			sycho_header_style_3();
		} elseif ($sycho_default_header_style == 'header-style-4') {
			sycho_header_style_4();
		} else {
			sycho_header_style_1();
		}
	}
}

add_action('sycho_header_style', 'sycho_check_header', 10);

/**
 * header style 1 + default
 */

function sycho_header_style_1()
{
	// top info
	$sycho_opening_label = get_theme_mod('sycho_opening_label', esc_html__('opening:', 'sycho'));
	$sycho_opening = get_theme_mod('sycho_opening', esc_html__('Sunday to Thursday', 'sycho'));
	$sycho_opening_icon = get_theme_mod('sycho_opening_icon', esc_html__('icon flaticon-history', 'sycho'));

	$sycho_mail_label = get_theme_mod('sycho_mail_label', esc_html__('e-mail:', 'sycho'));
	$sycho_mail_id = get_theme_mod('sycho_mail_id', esc_html__('info@sycho24.com', 'sycho'));
	$sycho_mail_icon = get_theme_mod('sycho_mail_icon', esc_html__('icon flaticon-envelope', 'sycho'));

	$sycho_phone_label = get_theme_mod('sycho_phone_label', esc_html__('Call us:', 'sycho'));
	$sycho_phone = get_theme_mod('sycho_phone', esc_html__('(202) 588-6500', 'sycho'));
	$sycho_phone_icon = get_theme_mod('sycho_phone_icon', esc_html__('icon flaticon-24-hours-support', 'sycho'));

	// sycho_header_bar_switch
	$sycho_header_top_right_switch = get_theme_mod('sycho_header_top_right_switch', false);
	$sycho_show_button = get_theme_mod('sycho_show_button', false);
	$sycho_social_switch = get_theme_mod('sycho_social_switch', false);

	// sycho_header_right switch
	$sycho_header_right = get_theme_mod('sycho_header_right', false);
	$sycho_menu_col = $sycho_header_right ? 'col-xl-7 col-lg-8 col-md-10' : 'col-xl-12';

	$btn_text = get_theme_mod('sycho_button_text', esc_html__('Get A Quote', 'sycho'));
	$btn_link = get_theme_mod('sycho_button_link', esc_url('#'));

?>

	<!-- header area start 1 -->
	<header>
		<div class="header-area">
			<div class="header__top border-bottom-1 box-105">
				<div class="container-fluid">
					<div class="row align-items-center">
						<div class="col-xl-2 col-lg-3 col-md-4 col-sm-6 col-8">
							<div class="header__top-left">
								<div class="logo-2 logo-3">
									<?php sycho_header_logo(); ?>
								</div>
							</div>
						</div>

						<div class="col-xl-10 col-lg-9 col-md-8 col-sm-6 col-4">
							<div class="header__top-right d-flex justify-content-end">
								<div class="header-bar info-toggle-btn f-right d-md-none">
									<span></span>
									<span></span>
									<span></span>
								</div>

								<?php if (!empty($sycho_header_top_right_switch)) : ?>
									<?php if (!empty($sycho_opening)) : ?>
										<div class="header__info d-none d-lg-flex">
											<div class="header__info-icon">
												<span class="<?php print esc_attr($sycho_opening_icon); ?>"></span>
											</div>
											<div class="header__info-text">
												<span><?php print esc_html($sycho_opening_label); ?></span>
												<span><?php print esc_html($sycho_opening); ?></span>
											</div>
										</div>
									<?php endif; ?>

									<?php if (!empty($sycho_phone)) : ?>
										<div class="header__info d-none d-md-flex">
											<div class="header__info-icon">
												<span class="<?php print esc_attr($sycho_phone_icon); ?>"></span>
											</div>
											<div class="header__info-text">
												<span><?php print esc_html($sycho_phone_label); ?></span>
												<span><?php print esc_html($sycho_phone); ?></span>
											</div>
										</div>
									<?php endif; ?>

									<?php if (!empty($sycho_mail_id)) : ?>
										<div class="header__info d-none d-md-flex">
											<div class="header__info-icon">
												<span class="<?php print esc_attr($sycho_mail_icon); ?>"></span>
											</div>
											<div class="header__info-text">
												<span><?php print esc_html($sycho_mail_label); ?></span>
												<span><?php print esc_html($sycho_mail_id); ?></span>
											</div>
										</div>
									<?php endif; ?>
								<?php endif; ?>
							</div>
						</div>
					</div>
				</div>
			</div>
			<div class="header__bottom-3 d-none d-md-block box-105">
				<div class="container-fluid">
					<div class="row align-items-center">

						<div class="<?php print esc_attr($sycho_menu_col); ?>">
							<div class="main-menu main-menu-2 main-menu-3 d-none d-md-block">
								<nav>
									<?php sycho_header_menu(); ?>
								</nav>
							</div>
						</div>

						<?php if (!empty($sycho_header_right)) : ?>
							<div class="col-xl-5 col-lg-4 col-md-2">
								<div class="header__bottom-3-right d-flex justify-content-end align-items-center">
									<?php if (!empty($sycho_social_switch)) : ?>
										<div class="social social-border d-none d-xl-block">
											<?php sycho_header_social_profiles(); ?>
										</div>
									<?php endif; ?>

									<?php if (!empty($sycho_show_button)) : ?>
										<?php if (!empty($btn_link)) : ?>
											<div class="header__btn ml-35 d-none d-lg-block">
												<a href="<?php print esc_html($btn_link); ?>" class="s-btn s-btn__square"><?php print esc_html($btn_text); ?></a>
											</div>
										<?php endif; ?>
									<?php endif; ?>
								</div>
							</div>
						<?php endif; ?>
					</div>
				</div>
			</div>
		</div>
	</header>
	<!-- header area start -->

	<!-- info area start -->
	<section class="info__area transition-3">
		<div class="info__area-inner">
			<div class="info__area-wrapper info__area-wrapper-3">
				<div class="info__close-icon text-right">
					<button class="info-close-btn"><i class="fal fa-times"></i></button>
				</div>
			</div>
			<!-- side-mobile-menu start -->
			<nav class="side-mobile-menu side-mobile-menu-3">
				<div class="info__close-icon text-right">
					<button class="info-close-btn"><i class="fal fa-times"></i></button>
				</div>
				<?php sycho_mobile_menu(); ?>
			</nav>
			<!-- side-mobile-menu end -->
		</div>
	</section>
	<div class="body-overlay transition-3"></div>
	<!-- info area end -->
<?php
}

/**
 * header style 2
 */
function sycho_header_style_2()
{

	$sycho_phone = get_theme_mod('sycho_phone', esc_html__('(202) 588-6500', 'sycho'));
	$sycho_phone_icon = get_theme_mod('sycho_phone_icon', esc_html__('icon flaticon-24-hours-support', 'sycho'));

	$sycho_logo = get_template_directory_uri() . '/assets/img/logo/logo.png';
	$sycho_offset_logo = get_theme_mod('offset_info_logo', $sycho_logo);
	$offset_info_content = get_theme_mod('offset_info_content');
	$offset_social_switch = get_theme_mod('offset_social_switch', false);
	$offset_fb_url = get_theme_mod('offset_fb_url', __('#', 'sycho'));
	$offset_twitter_url = get_theme_mod('offset_twitter_url', __('#', 'sycho'));
	$offset_instagram_url = get_theme_mod('offset_instagram_url', __('#', 'sycho'));
	$offset_linkedin_url = get_theme_mod('offset_linkedin_url', __('#', 'sycho'));
	$offset_youtube_url = get_theme_mod('offset_youtube_url', __('#', 'sycho'));
?>
	<!-- header area 2 -->
	<header>
		<div class="header-area tranparent-header box-105">
			<div class="container-fluid">
				<div class="row align-items-center">
					<div class="col-xl-2 col-lg-2 col-md-3 col-sm-6 col-6">
						<div class="logo">
							<?php sycho_header_logo(); ?>
						</div>
					</div>
					<div class="col-xl-7 col-lg-9 d-none d-lg-block">
						<!-- menu area start -->
						<div class="main-menu">
							<nav>
								<?php sycho_header_menu(); ?>
							</nav>
						</div>
						<!-- menu area end -->
					</div>
					<div class="col-xl-3 col-lg-1 col-md-9 col-sm-6 col-6">
						<div class="header-bar info-toggle-btn f-right">
							<span></span>
							<span></span>
							<span></span>
						</div>
						<?php if (!empty($sycho_phone)) : ?>
							<div class="header-cta f-right d-none d-sm-inline-block d-md-inline-block d-lg-none d-xl-inline-block">
								<span class="<?php print esc_attr($sycho_phone_icon); ?>">
									<a href="#"><?php print esc_html($sycho_phone); ?></a>
								</span>
							</div>
						<?php endif; ?>
					</div>
				</div>
			</div>
		</div>
	</header>

	<!-- info area start -->
	<section class="info__area transition-3">
		<div class="info__area-inner">
			<div class="info__area-wrapper info__area-wrapper-3">
				<div class="info__close-icon text-right">
					<button class="info-close-btn"><i class="fal fa-times"></i></button>
				</div>
				<div class="info__wrapper">
					<?php if (!empty($sycho_offset_logo)) : ?>
						<div class="info__logo mb-30">
							<a href="<?php print esc_url(home_url('/')); ?>">
								<img src="<?php echo esc_url($sycho_offset_logo); ?>" alt="<?php print esc_attr__('logo', 'sycho') ?>">
							</a>
						</div>
					<?php endif; ?>
					<?php if ($offset_social_switch == true || !empty($offset_info_content)) : ?>
						<div class="info__content mb-50">
							<p><?php print esc_html($offset_info_content) ?></p>
							<?php if ($offset_social_switch == true) : ?>
								<div class="side-social">
									<ul>
										<?php if (!empty($offset_fb_url)) : ?>
											<li><a href="<?php print esc_url($offset_fb_url); ?>" data-bg-color="#1b4195"><i class="fab fa-facebook-f"></i></a></li>
										<?php endif; ?>

										<?php if (!empty($offset_twitter_url)) : ?>
											<li><a href="<?php print esc_url($offset_twitter_url); ?>" data-bg-color="#0e97d1"><i class="fab fa-twitter"></i></a></li>
										<?php endif; ?>

										<?php if (!empty($offset_instagram_url)) : ?>
											<li><a href="<?php print esc_url($offset_instagram_url); ?>" data-bg-color="#b41a32"><i class="fab fa-instagram"></i></a></li>
										<?php endif; ?>

										<?php if (!empty($offset_linkedin_url)) : ?>
											<li><a href="<?php print esc_url($offset_linkedin_url); ?>" data-bg-color="#0f72aa"><i class="fab fa-linkedin"></i></a></li>
										<?php endif; ?>

										<?php if (!empty($offset_youtube_url)) : ?>
											<li><a href="<?php print esc_url($offset_youtube_url); ?>" data-bg-color="#b41a32"><i class="fab fa-youtube"></i></a></li>
										<?php endif; ?>
									</ul>
								</div>
							<?php endif; ?>
						</div>
					<?php endif; ?>
					<?php
					if (is_active_sidebar('offset-sidebar')) {
						dynamic_sidebar('offset-sidebar');
					}
					?>
				</div>
			</div>
			<!-- side-mobile-menu start -->
			<nav class="side-mobile-menu side-mobile-menu-3">
				<div class="info__close-icon text-right mb-20">
					<button class="info-close-btn"><i class="fal fa-times"></i></button>
				</div>
				<?php sycho_mobile_menu(); ?>
			</nav>
			<!-- side-mobile-menu end -->
		</div>
	</section>
	<div class="body-overlay transition-3"></div>
	<!-- info area end -->
<?php
}

/**
 * header style 3
 */
function sycho_header_style_3()
{
	// top left
	$sycho_mail_label = get_theme_mod('sycho_mail_label', esc_html__('e-mail:', 'sycho'));
	$sycho_mail_id = get_theme_mod('sycho_mail_id', esc_html__('info@sycho24.com', 'sycho'));
	$sycho_mail_icon = get_theme_mod('sycho_mail_icon', esc_html__('icon flaticon-envelope', 'sycho'));

	$sycho_phone_label = get_theme_mod('sycho_phone_label', esc_html__('Call us:', 'sycho'));
	$sycho_phone = get_theme_mod('sycho_phone', esc_html__('(202) 588-6500', 'sycho'));
	$sycho_phone_icon = get_theme_mod('sycho_phone_icon', esc_html__('icon flaticon-24-hours-support', 'sycho'));


	$sycho_topbar_switch = get_theme_mod('sycho_topbar_switch', true);

	$btn_text = get_theme_mod('sycho_button_text', 'Contact Us Now');


	$btn_link = get_theme_mod('sycho_button_link', '#');

?>
	<!-- header style 3 -->
	<header>
		<div class="header-area">
			<?php if (!empty($sycho_topbar_switch)) : ?>
				<div class="header__top header__top-bg box-105">
					<div class="container-fluid">
						<div class="row align-items-center">
							<div class="col-xl-6 col-lg-6 col-md-4 col-sm-7 d-none d-sm-block">
								<div class="header__top-left">
									<div class="social">
										<?php sycho_header_social_profiles(); ?>
									</div>
								</div>
							</div>
							<div class="col-xl-6 col-lg-6 col-md-8 col-sm-5 col-12">
								<div class="header__top-right d-flex justify-content-end">

									<?php if (!empty($sycho_phone)) : ?>
										<div class="header__info d-none d-sm-none d-md-flex">
											<div class="header__info-icon">
												<span class="<?php print esc_attr($sycho_phone_icon); ?>"></span>
											</div>
											<div class="header__info-text">
												<span><?php print esc_html($sycho_phone_label); ?></span>
												<span><?php print esc_html($sycho_phone); ?></span>
											</div>
										</div>
									<?php endif; ?>

									<?php if (!empty($sycho_mail_id)) : ?>
										<div class="header__info d-none d-sm-flex">
											<div class="header__info-icon">
												<span class="<?php print esc_attr($sycho_mail_icon); ?>"></span>
											</div>
											<div class="header__info-text">
												<span><?php print esc_html($sycho_mail_label); ?></span>
												<span><?php print esc_html($sycho_mail_id); ?></span>
											</div>
										</div>
									<?php endif; ?>
								</div>
							</div>
						</div>
					</div>
				</div>
			<?php endif; ?>
			<div class="header__bottom box-105">
				<div class="container-fluid">
					<div class="row">
						<div class="col-xl-2 col-lg-3 col-md-4 col-sm-6 col-8">
							<div class="logo-2">
								<?php sycho_header_logo(); ?>
							</div>
						</div>
						<div class="col-xl-10 col-lg-9 col-md-8 col-sm-6 col-4">
							<div class="header__bottom-right pink-soft-bg d-flex justify-content-end justify-content-lg-between align-items-center">
								<div class="main-menu main-menu-2 d-none d-lg-block">
									<nav>
										<?php sycho_header_menu(); ?>
									</nav>
								</div>
								<div class="header-bar info-toggle-btn d-lg-none f-right">
									<span></span>
									<span></span>
									<span></span>
								</div>
								<?php if (!empty($btn_link)) : ?>
									<div class="header__btn d-none d-xl-block">
										<a href="<?php print esc_url($btn_link); ?>" class="s-btn s-btn__square"><?php print esc_html($btn_text); ?> </a>
									</div>
								<?php endif; ?>
							</div>
						</div>
					</div>
				</div>
			</div>
		</div>
	</header>

	<!-- info area start -->
	<section class="info__area transition-3">
		<div class="info__area-inner">
			<!-- side-mobile-menu start -->
			<nav class="side-mobile-menu">
				<div class="info__close-icon text-right mb-20">
					<button class="info-close-btn"><i class="fal fa-times"></i></button>
				</div>
				<?php sycho_mobile_menu(); ?>
			</nav>
			<!-- side-mobile-menu end -->
		</div>
	</section>
	<div class="body-overlay transition-3"></div>
	<!-- info area end -->
	<?php
}


/**
 * [sycho_header_lang description]
 * @return [type] [description]
 */
function sycho_header_lang_defualt()
{
	$sycho_header_lang = get_theme_mod('sycho_header_lang', false);
	if ($sycho_header_lang) : ?>

		<ul>
			<li><a href="#0" class="lang__btn"><?php print esc_html__('EN', 'sycho'); ?> <i class="ti-arrow-down"></i></a>
				<?php do_action('sycho_language'); ?>
			</li>
		</ul>

	<?php endif; ?>
<?php
}


/**
 * [sycho_language_list description]
 * @return [type] [description]
 */
function _sycho_language($mar)
{
	return $mar;
}

function sycho_language_list()
{

	$mar = '';
	$languages = apply_filters('wpml_active_languages', NULL, 'orderby=id&order=desc');
	if (!empty($languages)) {
		$mar = '<ul>';
		foreach ($languages as $lan) {
			$active = $lan['active'] == 1 ? 'active' : '';
			$mar .= '<li class="' . $active . '"><a href="' . $lan['url'] . '">' . $lan['translated_name'] . '</a></li>';
		}
		$mar .= '</ul>';
	} else {
		//remove this code when send themeforest reviewer team
		$mar .= '<ul>';
		$mar .= '<li><a href="#">' . esc_html__('USA', 'sycho') . '</a></li>';
		$mar .= '<li><a href="#">' . esc_html__('UK', 'sycho') . '</a></li>';
		$mar .= '<li><a href="#">' . esc_html__('CA', 'sycho') . '</a></li>';
		$mar .= '<li><a href="#">' . esc_html__('AU', 'sycho') . '</a></li>';
		$mar .= ' </ul>';
	}
	print _sycho_language($mar);
}

add_action('sycho_language', 'sycho_language_list');

// favicon logo
function sycho_favicon_logo_func()
{
	$sycho_favicon = get_template_directory_uri() . '/assets/img/logo/favicon.jpg';
	$sycho_favicon_url = get_theme_mod('favicon_url', $sycho_favicon);
?>

	<link rel="shortcut icon" type="image/x-icon" href="<?php print esc_url($sycho_favicon_url); ?>">

<?php
}

add_action('wp_head', 'sycho_favicon_logo_func');

// header logo
function sycho_header_logo()
{
?>
	<?php
	$sycho_logo_on = function_exists('get_field') ? get_field('is_enable_sec_logo') : NULL;
	$sycho_logo = get_template_directory_uri() . '/assets/img/logo/logo.png';
	$sycho_logo_white = get_template_directory_uri() . '/assets/img/logo/logo-light.png';

	$sycho_site_logo = get_theme_mod('logo', $sycho_logo);
	$sycho_secondary_logo = get_theme_mod('seconday_logo', $sycho_logo_white);
	?>

	<?php
	if (has_custom_logo()) {
		the_custom_logo();
	} else {

		if (!empty($sycho_logo_on)) { ?>
			<a class="standard-logo" href="<?php print esc_url(home_url('/')); ?>">
				<img src="<?php print esc_url($sycho_secondary_logo); ?>" alt="<?php print esc_attr__('logo', 'sycho'); ?>" />
			</a>
		<?php
		} else { ?>
			<a class="standard-logo-white" href="<?php print esc_url(home_url('/')); ?>">
				<img src="<?php print esc_url($sycho_site_logo); ?>" alt="<?php print esc_attr__('logo', 'sycho'); ?>" />
			</a>
	<?php
		}
	}
	?>
<?php
}


/**
 * [sycho_header_social_profiles description]
 * @return [type] [description]
 */
function sycho_header_social_profiles()
{
	$sycho_topbar_fb_url = get_theme_mod('sycho_topbar_fb_url', __('#', 'sycho'));
	$sycho_topbar_twitter_url = get_theme_mod('sycho_topbar_twitter_url', __('#', 'sycho'));
	$sycho_topbar_instagram_url = get_theme_mod('sycho_topbar_instagram_url', __('#', 'sycho'));
	$sycho_topbar_linkedin_url = get_theme_mod('sycho_topbar_linkedin_url', __('#', 'sycho'));
	$sycho_topbar_youtube_url = get_theme_mod('sycho_topbar_youtube_url', __('#', 'sycho'));
?>
	<ul>
		<?php if (!empty($sycho_topbar_fb_url)) : ?>
			<li><a href="<?php print esc_url($sycho_topbar_fb_url); ?>"><i class="fab fa-facebook-f"></i></a></li>
		<?php endif; ?>

		<?php if (!empty($sycho_topbar_twitter_url)) : ?>
			<li><a href="<?php print esc_url($sycho_topbar_twitter_url); ?>"><i class="fab fa-twitter"></i></a></li>
		<?php endif; ?>

		<?php if (!empty($sycho_topbar_instagram_url)) : ?>
			<li><a href="<?php print esc_url($sycho_topbar_instagram_url); ?>"><i class="fab fa-instagram"></i></a></li>
		<?php endif; ?>

		<?php if (!empty($sycho_topbar_linkedin_url)) : ?>
			<li><a href="<?php print esc_url($sycho_topbar_linkedin_url); ?>"><i class="fab fa-linkedin"></i></a></li>
		<?php endif; ?>

		<?php if (!empty($sycho_topbar_youtube_url)) : ?>
			<li><a href="<?php print esc_url($sycho_topbar_youtube_url); ?>"><i class="fab fa-youtube"></i></a></li>
		<?php endif; ?>
	</ul>
<?php
}


function sycho_footer_social_profiles()
{
	$sycho_footer_fb_url = get_theme_mod('sycho_footer_fb_url', __('#', 'sycho'));
	$sycho_footer_twitter_url = get_theme_mod('sycho_footer_twitter_url', __('#', 'sycho'));
	$sycho_footer_vine_url = get_theme_mod('sycho_footer_vine_url', __('#', 'sycho'));
	$sycho_footer_weebly_url = get_theme_mod('sycho_footer_weebly_url', __('#', 'sycho'));
	$sycho_footer_vuejs_url = get_theme_mod('sycho_footer_vuejs_url', __('#', 'sycho'));
?>
	<ul class="mb-0">
		<?php if ($sycho_footer_fb_url) : ?>
			<li><a href="<?php print esc_url($sycho_footer_fb_url); ?>"><i class="fab fa-facebook-f"></i></a></li>
		<?php endif; ?>

		<?php if ($sycho_footer_twitter_url) : ?>
			<li><a href="<?php print esc_url($sycho_footer_twitter_url); ?>"><i class="fab fa-twitter"></i></a></li>
		<?php endif; ?>

		<?php if ($sycho_footer_vine_url) : ?>
			<li><a href="<?php print esc_url($sycho_footer_vine_url); ?>"><i class="fab fa-vine"></i></a></li>
		<?php endif; ?>

		<?php if ($sycho_footer_weebly_url) : ?>
			<li><a href="<?php print esc_url($sycho_footer_weebly_url); ?>"><i class="fab fa-weebly"></i></a></li>
		<?php endif; ?>

		<?php if ($sycho_footer_vuejs_url) : ?>
			<li><a href="<?php print esc_url($sycho_footer_vuejs_url); ?>"><i class="fab fa-vuejs"></i></a></li>
		<?php endif; ?>
	</ul>
	<?php
}

/**
 * [sycho_header_button description]
 * @return [type] [description]
 */
function sycho_header_button()
{
	$header_show_button = get_theme_mod('sycho_show_header_button', false);
	$header_btn_text = get_theme_mod('sycho_header_btn_text', __('Consultancy', 'sycho'));
	$header_btn_icon = get_theme_mod('sycho_header_btn_icon', __('far fa-long-arrow-right', 'sycho'));
	$header_btn_link = get_theme_mod('sycho_header_btn_link', __('#', 'sycho'));

	if ($header_show_button && !empty($header_btn_text)) : ?>
		<a class="btn" href="<?php print esc_url($header_btn_link); ?>"><span class="btn-text"><?php print esc_html($header_btn_text); ?> <i class="<?php print esc_attr($header_btn_icon); ?>"></i></span> </a>
	<?php endif; ?>

<?php
}


/**
 * [sycho_header_menu description]
 * @return [type] [description]
 */
function sycho_header_menu()
{ ?>
	<?php
	wp_nav_menu(array(
		'theme_location' => 'main-menu',
		'menu_class' => '',
		'container' => '',
		'fallback_cb' => 'Navwalker_Class::fallback',
		'walker' => new Navwalker_Class
	));
	?>
<?php
}

/**
 * [sycho_header_menu left description]
 * @return [type] [description]
 */
function sycho_header_left_menu()
{ ?>
	<?php
	wp_nav_menu(array(
		'theme_location' => 'main-left-menu',
		'menu_class' => '',
		'container' => '',
		'fallback_cb' => 'Navwalker_Class::fallback',
		'walker' => new Navwalker_Class
	));
	?>
<?php
}

/**
 * [sycho_header_menu left description]
 * @return [type] [description]
 */
function sycho_header_right_menu()
{ ?>
	<?php
	wp_nav_menu(array(
		'theme_location' => 'main-right-menu',
		'menu_class' => '',
		'container' => '',
		'fallback_cb' => 'Navwalker_Class::fallback',
		'walker' => new Navwalker_Class
	));
	?>
<?php
}


/**
 * [sycho_header_menu description]
 * @return [type] [description]
 */
function sycho_mobile_menu()
{ ?>
	<?php
	$sycho_menu = wp_nav_menu(array(
		'theme_location' => 'main-menu',
		'menu_class' => '',
		'container' => '',
		'menu_id' => 'mobile-menu-active',
		'echo' => false
	));

	$sycho_menu = str_replace("menu-item-has-children", "menu-item-has-children has-children", $sycho_menu);
	echo wp_kses_post($sycho_menu);
	?>
<?php
}


function sycho_header_3_menu()
{ ?>
	<?php
	wp_nav_menu(array(
		'theme_location' => 'main-menu',
		'menu_class' => '',
		'container' => '',
	));
	?>
<?php
}


/**
 * [sycho_footer_menu description]
 * @return [type] [description]
 */
function sycho_footer_menu()
{

	wp_nav_menu(array(
		'theme_location' => 'footer-menu',
		'menu_class' => 'm-0',
		'container' => '',
		'fallback_cb' => 'Navwalker_Class::fallback',
		'walker' => new Navwalker_Class
	));
}


/**
 *
 * sycho footer
 */
add_action('sycho_footer_style', 'sycho_check_footer', 10);

function sycho_check_footer()
{
	$sycho_footer_style = function_exists('get_field') ? get_field('footer_style') : NULL;
	$sycho_default_footer_style = get_theme_mod('choose_default_footer', 'footer-style-1');


	if ($sycho_footer_style == 'footer-style-1') {
		sycho_footer_style_1();
	} elseif ($sycho_footer_style == 'footer-style-2') {
		sycho_footer_style_2();
	} elseif ($sycho_footer_style == 'footer-style-3') {
		sycho_footer_style_3();
	} else {

		/** default footer style **/
		if ($sycho_default_footer_style == 'footer-style-2') {
			sycho_footer_style_2();
		} elseif ($sycho_default_footer_style == 'footer-style-3') {
			sycho_footer_style_3();
		} else {
			sycho_footer_style_1();
		}
	}
}

/**
 * footer  style_defaut
 */
function sycho_footer_style_1()
{

	$footer_bg_img = get_theme_mod('sycho_footer_bg');
	$footer_social_switch = get_theme_mod('footer_social_switch', false);;
	$copyright_column = is_active_sidebar('footer-bottom-menu') ? 'col-xl-6 col-lg-6 col-md-6' : 'col-md-12 text-center';
	$sycho_footer_bg_url_from_page = function_exists('get_field') ? get_field('sycho_footer_bg') : '';
	$sycho_footer_bg_color_from_page = function_exists('get_field') ? get_field('sycho_footer_bg_color') : '';
	$footer_bg_color = get_theme_mod('sycho_footer_bg_color');

	// bg image
	$bg_img = !empty($sycho_footer_bg_url_from_page['url']) ? $sycho_footer_bg_url_from_page['url'] : $footer_bg_img;

	// bg color
	$bg_color = !empty($sycho_footer_bg_color_from_page) ? $sycho_footer_bg_color_from_page : $footer_bg_color;

	// footer_columns
	$footer_columns = 0;
	$footer_widgets = get_theme_mod('footer_widget_number', 4);

	for ($num = 1; $num <= $footer_widgets; $num++) {
		if (is_active_sidebar('footer-' . $num)) {
			$footer_columns++;
		}
	}

	switch ($footer_columns) {
		case '1':
			$footer_class[1] = 'col-lg-12';
			break;
		case '2':
			$footer_class[1] = 'col-lg-6 col-md-6';
			$footer_class[2] = 'col-lg-6 col-md-6';
			break;
		case '3':
			$footer_class[1] = 'col-xl-4 col-lg-6 col-md-5';
			$footer_class[2] = 'col-xl-4 col-lg-6 col-md-7';
			$footer_class[3] = 'col-xl-4 col-lg-6';
			break;
		case '4':
			$footer_class[1] = 'col-xl-3 col-lg-6 col-md-6 col-sm-6 mb-50';
			$footer_class[2] = 'col-xl-3 col-lg-6 col-md-6 col-sm-6 mb-50 pl-30';
			$footer_class[3] = 'col-xl-3 col-lg-6 col-md-6 col-sm-6 mb-50';
			$footer_class[4] = 'col-xl-3 col-lg-6 col-md-6 col-sm-6 mb-50';
			break;
		default:
			$footer_class = 'col-xl-4 col-lg-4 col-md-6';
			break;
	}

?>

	<footer>
		<div class="footer__area">
			<?php if (is_active_sidebar('footer-1') or is_active_sidebar('footer-2') or is_active_sidebar('footer-3') or is_active_sidebar('footer-4')) : ?>
				<div class="footer__bottom footer-bg pt-120 pb-50">
					<div class="container">
						<div class="row">
							<?php
							if ($footer_columns < 4) {
								print '<div class="col-xl-3 col-lg-6 col-md-6 col-sm-6 mb-50">';
								dynamic_sidebar('footer-1');
								print '</div>';

								print '<div class="col-xl-3 col-lg-6 col-md-6 col-sm-6 mb-50 pl-30">';
								dynamic_sidebar('footer-2');
								print '</div>';

								print '<div class="col-xl-3 col-lg-6 col-md-6 col-sm-6 mb-50">';
								dynamic_sidebar('footer-3');
								print '</div>';

								print '<div class="col-xl-3 col-lg-6 col-md-6 col-sm-6 mb-50">';
								dynamic_sidebar('footer-4');
								print '</div>';
							} else {
								for ($num = 1; $num <= $footer_columns; $num++) {
									if (!is_active_sidebar('footer-' . $num)) continue;
									print '<div class="' . esc_attr($footer_class[$num]) . '">';
									dynamic_sidebar('footer-' . $num);
									print '</div>';
								}
							}

							?>
						</div>
					</div>
				</div>
		</div>
	<?php endif; ?>

	<div class="footer__copyright footer__copyright-3 footer-bottom-bg">
		<div class="container">
			<div class="row">

				<div class="<?php print esc_attr($copyright_column); ?>">
					<div class="footer__copyright-text">
						<p><?php print sycho_copyright_text(); ?></p>
					</div>
				</div>

				<?php if (is_active_sidebar('footer-bottom-menu')) : ?>
					<div class="col-xl-6 col-lg-6 col-md-6">
						<?php dynamic_sidebar('footer-bottom-menu'); ?>
					</div>
				<?php endif; ?>
			</div>
		</div>
	</div>

	</footer>

<?php
}

/**
 * footer  style 2
 */
function sycho_footer_style_2()
{
	$footer_bg_img = get_theme_mod('sycho_footer_bg');
	$copyright_column = is_active_sidebar('footer-bottom-menu') ? 'col-sm-6' : 'col-sm-12 text-center';
	$sycho_footer_bg_url_from_page = function_exists('get_field') ? get_field('sycho_footer_bg') : '';
	$sycho_footer_bg_color_from_page = function_exists('get_field') ? get_field('sycho_footer_bg_color') : '';
	$footer_bg_color = get_theme_mod('sycho_footer_bg_color');

	// bg image
	$bg_img = !empty($sycho_footer_bg_url_from_page['url']) ? $sycho_footer_bg_url_from_page['url'] : $footer_bg_img;
	// bg color
	$bg_color = !empty($sycho_footer_bg_color_from_page) ? $sycho_footer_bg_color_from_page : $footer_bg_color;

	$footer_columns = 0;
	$footer_widgets = get_theme_mod('footer_widget_number', 4);

	for ($num = 1; $num <= $footer_widgets; $num++) {
		if (is_active_sidebar('footer-2-' . $num)) {
			$footer_columns++;
		}
	}


	switch ($footer_columns) {
		case '1':
			$footer_class[1] = 'col-lg-12';
			break;
		case '2':
			$footer_class[1] = 'col-lg-6 col-md-6';
			$footer_class[2] = 'col-lg-6 col-md-6';
			break;
		case '3':
			$footer_class[1] = 'col-xl-4 col-lg-6 col-md-5';
			$footer_class[2] = 'col-xl-4 col-lg-6 col-md-7';
			$footer_class[3] = 'col-xl-4 col-lg-6';
			break;
		case '4':
			$footer_class[1] = 'col-xl-3 col-lg-6 col-md-6 mb-50';
			$footer_class[2] = 'col-xl-2 col-lg-6 col-md-6 offset-xl-1 mb-50';
			$footer_class[3] = 'col-xl-2 col-lg-6 col-md-6 mb-50';
			$footer_class[4] = 'col-xl-3 col-lg-6 col-md-6 offset-xl-1 mb-50';
			break;
		default:
			$footer_class = 'col-xl-4 col-lg-4 col-md-6';
			break;
	}

?>


	<footer class="footer-bg">
		<div class="footer__area pt-130 box-105">
			<div class="container-fluid">
				<?php if (is_active_sidebar('footer-2-1') or is_active_sidebar('footer-2-2') or is_active_sidebar('footer-2-3') or is_active_sidebar('footer-2-4')) : ?>
					<div class="footer__bottom pb-70">
						<div class="row">
							<?php
							if ($footer_columns < 4) {
								print '<div class="col-xl-3 col-lg-6 col-md-6 mb-50">';
								dynamic_sidebar('footer-2-1');
								print '</div>';

								print '<div class="col-xl-2 col-lg-6 col-md-6 offset-xl-1 mb-50">';
								dynamic_sidebar('footer-2-2');
								print '</div>';

								print '<div class="col-xl-2 col-lg-6 col-md-6 mb-50">';
								dynamic_sidebar('footer-2-3');
								print '</div>';

								print '<div class="col-xl-3 col-lg-6 col-md-6 offset-xl-1 mb-50">';
								dynamic_sidebar('footer-2-4');
								print '</div>';
							} else {
								for ($num = 1; $num <= $footer_columns; $num++) {
									if (!is_active_sidebar('footer-2-' . $num)) continue;
									print '<div class="' . esc_attr($footer_class[$num]) . '">';
									dynamic_sidebar('footer-2-' . $num);
									print '</div>';
								}
							}

							?>
						</div>
					</div>
				<?php endif; ?>

				<div class="footer__copyright">
					<div class="row">
						<div class="<?php print esc_attr($copyright_column); ?>">
							<div class="footer__copyright-text">
								<p><?php print sycho_copyright_text(); ?></p>
							</div>
						</div>
						<?php if (is_active_sidebar('footer-bottom-menu')) : ?>
							<div class="col-sm-6">
								<?php dynamic_sidebar('footer-bottom-menu'); ?>
							</div>
						<?php endif; ?>
					</div>
				</div>
			</div>
		</div>
	</footer>

<?php
}


/**
 * footer  3
 */
function sycho_footer_style_3()
{

	$footer_bg_img = get_theme_mod('sycho_footer_bg');
	$sycho_footer_bg_url_from_page = function_exists('get_field') ? get_field('sycho_footer_bg') : '';
	$sycho_footer_bg_color_from_page = function_exists('get_field') ? get_field('sycho_footer_bg_color') : '';
	$footer_bg_color = get_theme_mod('sycho_footer_bg_color');

	// bg image
	$bg_img = !empty($sycho_footer_bg_url_from_page['url']) ? $sycho_footer_bg_url_from_page['url'] : $footer_bg_img;

	// bg color
	$bg_color = !empty($sycho_footer_bg_color_from_page) ? $sycho_footer_bg_color_from_page : $footer_bg_color;

	$footer_columns = 0;

	$footer_widgets = get_theme_mod('footer_widget_number', 3);

	for ($num = 1; $num <= $footer_widgets + 1; $num++) {
		if (is_active_sidebar('footer-3-' . $num)) {
			$footer_columns++;
		}
	}

	switch ($footer_columns) {
		case '1':
			$footer_class[1] = 'col-lg-12';
			break;
		case '2':
			$footer_class[1] = 'col-lg-6 col-md-6';
			$footer_class[2] = 'col-lg-6 col-md-6';
			break;
		case '3':
			$footer_class[1] = 'col-xl-4 col-lg-6 col-md-12';
			$footer_class[2] = 'col-xl-4 col-lg-6 col-sm-6 col-6';
			$footer_class[3] = 'col-xl-4 col-lg-6';
		case '4':
			$footer_class[1] = 'col-xl-4 col-lg-6 col-md-12';
			$footer_class[2] = 'col-xl-2 col-lg-6 col-sm-6 col-6';
			$footer_class[3] = 'col-xl-2 col-lg-6 col-sm-6 col-6';
			$footer_class[4] = 'col-xl-4 col-lg-6';
			break;
		default:
			$footer_class = 'col-xl-4 col-lg-4 col-md-6';
			break;
	}

?>

	<!-- footer area start -->
	<footer class="site-footer bg_img pt-100" data-bg-color="<?php print esc_attr($bg_color); ?>" data-background="<?php print esc_url($bg_img); ?>">
		<div class="container">
			<div class="row">
				<div class="col-xl-12 text-center">
					<a href="#" class="site-logo mb-50">
						<img src="<?php echo get_template_directory_uri(); ?>/img/logo/logo.png" alt="<?php print esc_attr__('Logo', 'sycho'); ?>">
					</a>
				</div>
				<div class="col-xl-12">
					<div class="footer-top mt-50 mb-80">
						<div class="footer__info">
							<div class="footer__info--item d-flex align-items-center">
								<div class="icon mr-20">
									<img src="<?php echo get_template_directory_uri(); ?>/img/icons/footer-info-icon-1.png" alt="<?php print esc_attr__('Logo', 'sycho'); ?>">
								</div>
								<div class="content">
									<h4 class="title"><?php print esc_html__('Phone Number', 'sycho'); ?></h4>
									<a href="#"><?php print esc_html__('+987 876 765 76 577', 'sycho'); ?></a>
								</div>
							</div>
							<div class="footer__info--item d-flex align-items-center">
								<div class="icon mr-20">
									<img src="<?php echo get_template_directory_uri(); ?>/img/icons/footer-info-icon-2.png" alt="<?php print esc_attr__('Logo', 'sycho'); ?>">
								</div>
								<div class="content">
									<h4 class="title"><?php print esc_html__('Email Address', 'sycho'); ?> </h4>
									<a href="#"><?php print esc_html__('info@webmail.com', 'sycho'); ?> </a>
								</div>
							</div>
							<div class="footer__info--item d-flex align-items-center">
								<div class="icon mr-20">
									<img src="<?php echo get_template_directory_uri(); ?>/img/icons/footer-info-icon-3.png" alt="<?php print esc_attr__('Logo', 'sycho'); ?>">
								</div>
								<div class="content">
									<h4 class="title"><?php print esc_html__('Office Address', 'sycho'); ?></h4>
									<span><?php print esc_html__('14/A, Miranda City, NYC', 'sycho'); ?></span>
								</div>
							</div>
						</div>
						<button id="scroll-top" class="site-btn transparent"><i class="fal fa-long-arrow-up"></i>
							<span><?php print esc_html__('Back To Top', 'sycho'); ?></span> <i class="fal fa-long-arrow-up"></i></button>
					</div>
				</div>
			</div>
		</div>
		<div class="container">
			<div class="row">
				<?php

				if ($footer_columns < 4) {
					print '<div class="col-xl-4 col-lg-6 col-md-12">';
					dynamic_sidebar('footer-3-1');
					print '</div>';

					print '<div class="col-xl-2 col-lg-6 col-sm-6 col-6">';
					dynamic_sidebar('footer-3-2');
					print '</div>';

					print '<div class="col-xl-2 col-lg-6 col-sm-6 col-6 mt-30">';
					dynamic_sidebar('footer-3-3');
					print '</div>';

					print '<div class="col-xl-4 col-lg-6">';
					dynamic_sidebar('footer-3-4');
					print '</div>';
				} else {
					for ($num = 1; $num <= $footer_columns; $num++) {
						if (!is_active_sidebar('footer-3-' . $num)) continue;
						print '<div class="' . esc_attr($footer_class[$num]) . '">';
						dynamic_sidebar('footer-3-' . $num);
						print '</div>';
					}
				}
				?>

			</div>
		</div>
		</div>
		<div class="container">
			<div class="row">
				<div class="col-xl-12">
					<div class="copyright-text mt-60">
						<div class="row">
							<div class="col-xl-12 text-center">
								<p><?php print sycho_copyright_text(); ?></p>
							</div>
						</div>
					</div>
				</div>
			</div>
		</div>
	</footer>
	<!-- footer area end -->

	<?php
}


function sycho_copyright_text()
{
	if (rtl_enable()) {
		print get_theme_mod('sycho_copyright_rtl', esc_html__('Copyright ©2022 ThemePure. All Rights Reserved', 'sycho'));
	} else {
		print get_theme_mod('sycho_copyright', esc_html__('Copyright ©2022 ThemePure. All Rights Reserved', 'sycho'));
	}
}

/**
 * [sycho_breadcrumb_func description]
 * @return [type] [description]
 */
function sycho_breadcrumb_func()
{

	$breadcrumb_class = '';
	$breadcrumb_show = 1;

	if (is_front_page() && is_home()) {
		$title = get_theme_mod('breadcrumb_blog_title', esc_html__('Blog', 'sycho'));
		$breadcrumb_class = 'home_front_page';
	} elseif (is_front_page()) {
		$title = get_theme_mod('breadcrumb_blog_title', esc_html__('Blog', 'sycho'));
		$breadcrumb_show = 0;
	} elseif (is_home()) {
		if (get_option('page_for_posts')) {
			$title = get_the_title(get_option('page_for_posts'));
		}
	} elseif (is_single() && 'post' == get_post_type()) {
		if (rtl_enable())
			$title = get_theme_mod('breadcrumb_blog_title_details_rtl', esc_html__('Blog', 'sycho'));
		else
			$title = get_the_title();
	} elseif (is_single() && 'product' == get_post_type()) {
		$title = get_theme_mod('breadcrumb_product_details', esc_html__('Shop', 'sycho'));
	} elseif (is_single() && 'bdevs-services' == get_post_type()) {
		if (rtl_enable())
			$title = get_theme_mod('breadcrumb_department_details_rtl', esc_html__('Services', 'sycho'));
		else
			$title = get_theme_mod('breadcrumb_department_details', esc_html__('Services', 'sycho'));
	} elseif (is_single() && 'bdevs-doctor' == get_post_type()) {
		if (rtl_enable())
			$title = get_theme_mod('breadcrumb_doctor_details_rtl', esc_html__('Doctor Details', 'sycho'));
		else
			$title = get_theme_mod('breadcrumb_doctor_details', esc_html__('Doctor Details', 'sycho'));
	} elseif (is_single() && 'bdevs-case_study' == get_post_type()) {
		if (rtl_enable())
			$title = get_theme_mod('breadcrumb_case_study_details_rtl', esc_html__('Gallery', 'sycho'));
		else
			$title = get_theme_mod('breadcrumb_case_study_details', esc_html__('Gallery', 'sycho'));
	} elseif (is_search()) {
		$title = get_theme_mod('breadcrumb_search', esc_html__('Search results for', 'sycho'));
	} elseif (is_404()) {
		$title = get_theme_mod('breadcrumb_404', esc_html__('Page Not Found', 'sycho'));
	} elseif (function_exists('is_woocommerce') && is_woocommerce()) {
		$title = get_theme_mod('breadcrumb_shop', esc_html__('Shop', 'sycho'));
	} elseif (is_archive()) {
		$title = get_the_archive_title();
	} else {
		$title = get_the_title();
	}

	$_id = get_the_ID();

	if (is_single() && 'product' == get_post_type()) {
		$_id = $post->ID;
	} elseif (function_exists("is_shop") and is_shop()) {
		$_id = wc_get_page_id('shop');
	} elseif (is_home() && get_option('page_for_posts')) {
		$_id = get_option('page_for_posts');
	}

	$is_breadcrumb = function_exists('get_field') ? get_field('is_it_invisible_breadcrumb', $_id) : '';
	if (!empty($_GET['s'])) {
		$is_breadcrumb = null;
	}


	if (empty($is_breadcrumb) && $breadcrumb_show == 1) {

		$bg_img_from_page = function_exists('get_field') ? get_field('breadcrumb_background_image') : '';
		$hide_bg_img = function_exists('get_field') ? get_field('hide_breadcrumb_background_image') : '';
		$back_title = function_exists('get_field') ? get_field('breadcrumb_back_title') : '';

		// get_theme_mod
		$bg_img = get_theme_mod('breadcrumb_bg_img');


		if ($hide_bg_img) {
			$bg_img = '';
		} else {
			$bg_img = !empty($bg_img_from_page) ? $bg_img_from_page['url'] : $bg_img;
		} ?>

		<section class="page__title p-relative pt-200 pb-200 <?php print esc_attr($breadcrumb_class); ?>" data-background="<?php print esc_attr($bg_img); ?>">
			<div class="container">
				<div class="row">
					<div class="col-xl-12 col-lg-12 col-md-12">
						<div class="page__title-inner text-center">
							<div class="page__title-breadcrumb">
								<div class="breadcrumb">
									<?php sycho_breadcrumb_callback(); ?>
								</div>
							</div>
							<h1><?php echo wp_kses_post($title); ?></h1>
						</div>
					</div>
				</div>
			</div>
		</section>


	<?php
	}
}

add_action('sycho_before_main_content', 'sycho_breadcrumb_func');


function sycho_breadcrumb_callback()
{
	$args = array(
		'show_browse' => false,
		'post_taxonomy' => array('product' => 'product_cat')
	);
	$breadcrumb = new Breadcrumb_Class($args);

	return $breadcrumb->trail();
}


// gru_search_form
function sycho_search_form()
{ ?>
	<!-- Modal Search -->
	<div class="search-wrap d-none">
		<div class="search-inner">
			<i class="fal fa-times search-close" id="search-close"></i>
			<div class="search-cell">
				<form method="get" action="<?php print esc_url(home_url('/')); ?>">
					<div class="search-field-holder">
						<input type="search" name="s" class="main-search-input" value="<?php print esc_attr(get_search_query()) ?>" placeholder="<?php print esc_attr__('Search Your Keyword...', 'sycho'); ?>">
					</div>
				</form>
			</div>
		</div>
	</div>

<?php
}

add_action('sycho_before_main_content', 'sycho_search_form');

/**
 * comments form
 */
add_filter('comment_form_default_fields', 'sycho_comment_form_default_fields_func');

function sycho_comment_form_default_fields_func($default)
{
	$default['author'] = '<div class="row">
    <div class="col-xl-6">
    	<div class="contacts-name">
    		<label>' . esc_html__('Your name *', 'sycho') . '</label>
        	<input type="text" name="author">
        </div>
    </div>';
	$default['email'] = '<div class="col-xl-6">
		<div class="contacts-email ">
		<label>' . esc_html__('Your email *', 'sycho') . '</label>
        <input type="text" name="email">
    	</div>
    </div>';
	$default['url'] = '';

	$default['clients_commnet'] = '<div class="col-xl-12">
	<div class="contacts-message">
	<label>' . esc_html__('Comments *', 'sycho') . '</label>
     <textarea id="comment" name="comment" placeholder="Write your message.." cols="30" rows="10"></textarea>
    </div>';
	return $default;
}

add_filter('comment_form_defaults', 'sycho_comment_form_defaults_func');

function sycho_comment_form_defaults_func($info)
{
	if (!is_user_logged_in()) {
		$info['comment_field'] = '';
		$info['submit_field'] = '%1$s %2$s</div></div>';
	} else {
		$info['comment_field'] = '<div class="comments-textarea contacts-message contact-icon">
									
		<textarea id="comment" name="comment" placeholder="Write your message.." cols="30" rows="10"></textarea>';
		$info['submit_field'] = '%1$s %2$s</div>';
	}


	$info['submit_button'] = '<button class="s-btn s-btn__square s-btn__square-green" type="submit"><i class="fal fa-comments"></i> ' . esc_html__('Post Comment', 'sycho') . ' </button>';

	$info['title_reply_before'] = '<div class="post-comments-title">
                                        <h2>';
	$info['title_reply_after'] = '</h2></div>';
	$info['comment_notes_before'] = '';

	return $info;
}

/**
 *
 * pagination
 */
if (!function_exists('sycho_pagination')) {

	function _sycho_pagi_callback($pagination)
	{
		return $pagination;
	}

	//page navegation
	function sycho_pagination($prev, $next, $pages, $args)
	{
		global $wp_query, $wp_rewrite;
		$menu = '';
		$wp_query->query_vars['paged'] > 1 ? $current = $wp_query->query_vars['paged'] : $current = 1;

		if ($pages == '') {
			global $wp_query;
			$pages = $wp_query->max_num_pages;

			if (!$pages)
				$pages = 1;
		}

		$pagination = array(
			'base' => add_query_arg('paged', '%#%'),
			'format' => '',
			'total' => $pages,
			'current' => $current,
			'prev_text' => $prev,
			'next_text' => $next,
			'type' => 'array'
		);

		//rewrite permalinks
		if ($wp_rewrite->using_permalinks())
			$pagination['base'] = user_trailingslashit(trailingslashit(remove_query_arg('s', get_pagenum_link(1))) . 'page/%#%/', 'paged');

		if (!empty($wp_query->query_vars['s']))
			$pagination['add_args'] = array('s' => get_query_var('s'));

		$pagi = '';
		if (paginate_links($pagination) != '') {
			$paginations = paginate_links($pagination);
			$pagi .= '<ul>';
			foreach ($paginations as $key => $pg) {
				$pagi .= '<li>' . $pg . '</li>';
			}
			$pagi .= '</ul>';
		}

		print _sycho_pagi_callback($pagi);
	}
}


// rtl_enable
function rtl_enable()
{
	$my_current_lang = apply_filters('wpml_current_language', NULL);
	$rtl_enable = get_theme_mod('rtl_switch', false);
	if ($my_current_lang != 'en' && $rtl_enable) {
		return true;
	} else {
		return false;
	}
}

// theme color
function sycho_custom_color()
{
	$color_code = get_theme_mod('sycho_color_option', '#056c5f');
	wp_enqueue_style('sycho-custom', SYCHO_THEME_CSS_DIR . 'sycho-custom.css', array());
	if ($color_code != '') {
		$custom_css = '';
		$custom_css .= ".social.social-border ul li a:hover,.logo-2,.s-btn__square:hover,.slider-overlay-3::before,.play-btn.play-btn-pink:hover,.project__slider .owl-nav div button:hover,.project__thumb::after,.team-social-profile ul,.blog__date,.green-bg-2,#scroll a,.team__social ul li a:hover,.team__item:hover .team__content,.why__item:hover .why__icon i,.case__content-2::before,.faq__inner .card-header h5 button::before,.info__logo a,.header-bar span,.s-btn,.appointment__form-wrapper h1,.appointment__form-inner .sub-btn,.pricing__popular,.testimonial__person,.testimonial__slider .owl-nav div button::after,.testimonial__slider .owl-nav div.owl-next button::before,.sychologist__call span,.sidebar-list ul li a:hover::before,.case__details-video::before,.team__experience-area-item:hover,.event__date,.sidebar-tad li a:hover, .tagcloud a:hover,.postbox__gallery .owl-nav div button:hover,.basic-pagination-2 ul li span:hover, .basic-pagination ul li span.current,.basic-pagination-2 ul li a:hover, .basic-pagination-2 ul li.active a,.blog-post-tag a:hover, .features__icon i, .services__icon i, .services__item-2:hover, .services__content, .appointment__form-inner .sub-btn:hover, .services__history-year h2, .sidebar-search-form button { background: " . $color_code . "}";

		$custom_css .= ".link-btn,.social ul li a,.testimonial__slider-3 .owl-nav div button,.link-btn::after, .link-btn::before,.pricing__price,.testimonial__slider .owl-nav div button,.blog__meta span:hover a,.faq__inner .card-header h5 button.collapsed::before,.sidebar-list ul li a:hover,.team__social-2 ul li a:hover,.appointment__info ul li span i, .appointment__info ul li a i,.event__meta span i,.postbox__title a:hover,.blog__meta span:hover a i, .testimonial__info-3 h3, .slider-arrow a, .about-content h4, a.s-btn__white-2, .about-info-list span, .team__experience-area-item i, .appointment__info ul li span, .appointment__info ul li a, .basic-pagination ul li a { color: " . $color_code . "}";

		$custom_css .= ".social.social-border ul li a:hover,.team__item:hover .team__content,.testimonial__slider .owl-nav div button,.sidebar-list ul li a:hover,.sidebar-list-2 ul li:hover,#scroll a,.team__experience-area-item:hover,.basic-pagination-2 ul li span:hover, .basic-pagination ul li span.current,.basic-pagination-2 ul li a:hover, .basic-pagination-2 ul li.active a,.blog-post-tag a:hover,.contact__input-4:focus, .services__icon-3 i::after, .services__item-3:hover, .services__history-year h2::after { border-color: " . $color_code . "}";
		wp_add_inline_style('sycho-custom', $custom_css);
	}
}
add_action('wp_enqueue_scripts', 'sycho_custom_color');

// sec color
function sycho_sec_custom_color()
{
	$color_code = get_theme_mod('sycho_sec_color_option', '#f8a683');
	wp_enqueue_style('sycho-sec-custom', SYCHO_THEME_CSS_DIR . 'sycho-custom.css', array());
	if ($color_code != '') {
		$custom_css = '';
		$custom_css .= ".s-btn__square,.main-menu ul li::before,.play-btn.play-btn-pink,.slider-active .slick-dots li::before,.features__item:hover,.section__sub-title-3::after, .section__sub-title-3::before,.project__icon a:hover,.why__list ul li::before,.testimonial__video,.testimonial__slider-3 .owl-nav div.owl-next button::after,.footer__logo-area .social ul li a:hover,.appointment__form-inner,.why__icon i,.s-btn:hover,.about-info-list i,.sychologist__call:hover span,.sidebar-title h3::before,.case__menu button::before,.team__social-2 ul li a:hover,.team__details-title h2::before,.s-btn__square-green:hover,.contact__icon i, .services__item-2:hover .services__icon i, .social ul li a:hover, .services__item-2::after, .testimonial__slider-2 .owl-nav div button:hover, .services__content-inner a, .services__thumb::after, .services__history-item:hover .services__history-year h2, .testimonial__slider .owl-nav div button:hover::after { background: " . $color_code . "}";

		$custom_css .= ".main-menu ul li .submenu li:hover > a,.main-menu ul li:hover > a,.slider-area-3 .slick-dots li.slick-active button,.section__sub-title-2,.team-social-profile ul li a:hover,.counter__icon i::before,.blog__meta span i,.blog__content h2 a:hover,.footer__contact-item h6,.slider-content span,.slider-active-2 .slick-dots li.slick-active button,.faq__inner .card-header h5 button:hover,.blog__meta-2 span.date,.header-cta span,.plan-list li .icon,.testimonial__quote-2 span::before,.case__menu button.active,.case__menu button:hover,.team-member-info h3 a:hover,.contact-icon-4 i, .project__content h3 a:hover, .case__item-2:hover .case__content-2 h3 a:hover, .testimonial__content .rating ul li, .services__history-content h3:hover a, .testimonial__slider .owl-nav div button:hover, .event__details h3 a:hover { color: " . $color_code . "}";

		$custom_css .= ".main-menu ul li .submenu,.project__content h3 a:hover,.about__info-experience,.team__social-2 ul li a:hover,.contact__input-4.nice-select::after, .services__item-3:hover .services__icon-3 i::after, .testimonial__item-2, .pricing__price,
		.services__history-item:hover .services__history-year h2::after, .testimonial__slider .owl-nav div button:hover { border-color: " . $color_code . "}";
		wp_add_inline_style('sycho-sec-custom', $custom_css);
	}
}
add_action('wp_enqueue_scripts', 'sycho_sec_custom_color');

// heading color
function sycho_heading_custom_color()
{
	$color_code = get_theme_mod('sycho_heading_color_option', '#005046');
	wp_enqueue_style('sycho-heading-custom', SYCHO_THEME_CSS_DIR . 'sycho-custom.css', array());
	if ($color_code != '') {
		$custom_css = '';
		$custom_css .= "h1, h2, h3, h4, h5, h6 { color: " . $color_code . "}";
		wp_add_inline_style('sycho-sec-custom', $custom_css);
	}
}
add_action('wp_enqueue_scripts', 'sycho_heading_custom_color');


// heading color
function sycho_menu_custom_color()
{
	$color_code = get_theme_mod('sycho_menu_color_option', '#056c5f');
	wp_enqueue_style('sycho-menu-custom', SYCHO_THEME_CSS_DIR . 'sycho-custom.css', array());
	if ($color_code != '') {
		$custom_css = '';
		$custom_css .= ".main-menu-3 ul li a,.header__info-icon span::before,.header__info-text span,.main-menu-2 ul li a, .faq__inner .card-header h5 button { color: " . $color_code . "}";
		wp_add_inline_style('sycho-sec-custom', $custom_css);
	}
}
add_action('wp_enqueue_scripts', 'sycho_menu_custom_color');

// header top bg color
function sycho_breadcrumb_bg_color()
{
	$color_code = get_theme_mod('sycho_breadcrumb_bg_color', esc_html__('#222', 'sycho'));
	wp_enqueue_style('sycho-custom', SYCHO_THEME_CSS_DIR . 'sycho-custom.css', array());
	if ($color_code != '') {
		$custom_css = '';
		$custom_css .= ".breadcrumb-bg.gray-bg{ background: " . $color_code . "}";

		wp_add_inline_style('sycho-breadcrumb-bg', $custom_css);
	}
}

add_action('wp_enqueue_scripts', 'sycho_breadcrumb_bg_color');

// breadcrumb-spacing top
function sycho_breadcrumb_spacing()
{
	$padding_px = get_theme_mod('sycho_breadcrumb_spacing', esc_html__('160px', 'sycho'));
	wp_enqueue_style('sycho-custom', SYCHO_THEME_CSS_DIR . 'sycho-custom.css', array());
	if ($padding_px != '') {
		$custom_css = '';
		$custom_css .= ".breadcrumb-spacing{ padding-top: " . $padding_px . "}";

		wp_add_inline_style('sycho-breadcrumb-top-spacing', $custom_css);
	}
}

add_action('wp_enqueue_scripts', 'sycho_breadcrumb_spacing');

// breadcrumb-spacing bottom
function sycho_breadcrumb_bottom_spacing()
{
	$padding_px = get_theme_mod('sycho_breadcrumb_bottom_spacing', esc_html__('160px', 'sycho'));
	wp_enqueue_style('sycho-custom', SYCHO_THEME_CSS_DIR . 'sycho-custom.css', array());
	if ($padding_px != '') {
		$custom_css = '';
		$custom_css .= ".breadcrumb-spacing{ padding-bottom: " . $padding_px . "}";

		wp_add_inline_style('sycho-breadcrumb-bottom-spacing', $custom_css);
	}
}

add_action('wp_enqueue_scripts', 'sycho_breadcrumb_bottom_spacing');


// sycho_kses_intermediate
function sycho_kses_intermediate($string = '')
{
	return wp_kses($string, sycho_get_allowed_html_tags('intermediate'));
}

function sycho_get_allowed_html_tags($level = 'basic')
{
	$allowed_html = [
		'b' => [],
		'i' => [],
		'u' => [],
		'em' => [],
		'br' => [],
		'abbr' => [
			'title' => [],
		],
		'span' => [
			'class' => [],
		],
		'strong' => [],
		'a' => [
			'href' => [],
			'title' => [],
			'class' => [],
			'id' => []
		]
	];

	return $allowed_html;
}
